@@ -101,7 +101,7 @@ if (get_nfilter_request_var('action') == 'login') {
 		break;
 	case '3':
 		/* LDAP Auth */
- 		if ((get_nfilter_request_var('realm') == 'ldap') && (strlen(get_nfilter_request_var('login_password')) > 0)) {
+ 		if ((get_nfilter_request_var('realm') == '3') && (strlen(get_nfilter_request_var('login_password')) > 0)) {
 			/* include LDAP lib */
 			include_once('./lib/ldap.php');
 
