@@ -27,7 +27,9 @@ function run_data_query($host_id, $snmp_query_id) {
 
 	/* don't run/rerun the query if the host is down, or disabled */
 	$status = db_fetch_row_prepared('SELECT status, disabled FROM host WHERE id = ?', array($host_id));
-	if ($status['status'] == HOST_DOWN || $status['disabled'] == 'on') {
+	if (!sizeof($status)) {
+		return false;
+	}elseif ($status['status'] == HOST_DOWN || $status['disabled'] == 'on') {
 		return true;
 	}
 
@@ -553,32 +555,57 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 			query_debug_timer_offset('data_query', "Executing SNMP walk for data @ '" . $field_array['oid'] . "'");
 
-			if ($field_array['source'] == 'value') {
-				foreach($snmp_data as $oid => $value) {
-					$snmp_index = preg_replace((isset($field_array['oid_index_parse']) ? '/' . $field_array['oid_index_parse'] . '/' : $index_parse_regexp), "\\1", $oid);
+			if (preg_match('/^VALUE\/TABLE:(.*)/',$field_array["source"],$matches)) {
+				preg_match_all('/([^:]+):([^:]+)/',$matches[1],$match_temp);
+				$const_table = array_combine($match_temp[1],$match_temp[2]);
+			}
 
-					$oid = $field_array['oid'] . ".$snmp_index";
-
-					if ($field_name == 'ifOperStatus') {
-						if ((substr_count(strtolower($value), 'down')) ||
-							($value == '2')) {
-							$value = 'Down';
-						} elseif ((substr_count(strtolower($value), 'up')) ||
-							($value == '1')) {
-							$value = 'Up';
-						} elseif ((substr_count(strtolower($value), 'notpresent')) ||
-							($value == '6')) {
-							$value = 'notPresent';
-						}else{
-							$value = 'Testing';
-						}
+			if (preg_match('/^value/i',$field_array['source'])) {
+				foreach ($snmp_data as $oid => $value) {
+					$index_regex = (isset($field_array['oid_index_parse']) ? $field_array['oid_index_parse'] : $index_parse_regexp) . (isset($field_array['oid_suffix']) ? ('.' . $field_array['oid_suffix']) : '');
+					if (!preg_match($index_regex, $oid)) { 
+						continue;
 					}
 
-					debug_log_insert('data_query', "Found item [$field_name='$value'] index: $snmp_index [from value]");
-
-					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, $value , $snmp_index, $oid);
+					$snmp_index = preg_replace($index_regex,"\\1", $oid);
+					$oid = $field_array['oid'] . ".$snmp_index" . (isset($field_array['oid_suffix']) ? ('.' . $field_array['oid_suffix']) : '');
+					if ($field_name == 'ifOperStatus') {
+						switch(true) {
+							case preg_match('/^(down|2)/i',$value):
+								$value = 'Down';
+								break;
+							case preg_match('/^(up|1)/i',$value):
+								$value = 'Up';
+								break;
+							case preg_match('/^(notpresent|6)/i',$value):
+								$value = 'notPresent';
+								break;
+							default:
+								$value = 'Testing';
+						}
+						$mode = 'value';
+					} elseif (preg_match('/VALUE\/REGEXP:(.*)/',$field_array['source'],$matches)) {
+						$modified_value = preg_replace('/' . $matches[1] . '/', "\\1", $value);
+						$mode = 'regexp value parse';
+					} elseif (preg_match('/^VALUE\/TEST:(.*):(.*):(.*)/',$field_array['source'],$matches)) {
+						$modified_value = (strcmp($matches[1],$value) !== 0)?$matches[3]:$matches[2];
+						$mode = 'test value parse';
+					} elseif (preg_match('/^VALUE\/TABLE:(.*)/',$field_array['source'])) {
+						$modified_value = (array_key_exists($value,$const_table))?$const_table[$value]:'N/A';
+						$mode = 'table value parse';
+					} elseif (preg_match('/^VALUE\/HEX2IP:(\d+):(\d+)/',$field_array['source'],$matches)) {
+						#$modified_value = substr(str_replace(':','',$value),$matches[1],$matches[2]);
+						$modified_value = substr(preg_replace('/(:|HEX-)/','',$value),$matches[1],$matches[2]);
+						$modified_value = implode('.',unpack ('C*',pack('H*', $modified_value)));
+						$mode = 'hex2ip value parse';
+					} else {
+						$mode = 'value';
+					}
+					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, isset($modified_value)?$modified_value:$value , $snmp_index, $oid);
+					debug_log_insert('data_query', sprintf("Found item [%s='%s'] index: %s [from %s]",$field_name,isset($modified_value)?"$modified_value ($value)":$value,$snmp_index,$mode));
+					unset($modified_value);
 				}
-			}elseif (substr($field_array['source'], 0, 11) == 'OID/REGEXP:') {
+			} elseif (substr($field_array['source'], 0, 11) == 'OID/REGEXP:') {
 				foreach($snmp_data as $oid => $value) {
 					$parse_value = preg_replace('/' . str_replace('OID/REGEXP:', '', $field_array['source']) . '/', "\\1", $oid);
 
@@ -623,16 +650,6 @@ function query_snmp_host($host_id, $snmp_query_id) {
 
 					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, $parse_value, $snmp_index, $oid);
 				}
-			}elseif (substr($field_array['source'], 0, 13) == 'VALUE/REGEXP:') {
-				foreach($snmp_data as $oid => $value) {
-					$value = preg_replace('/' . str_replace('VALUE/REGEXP:', '', $field_array['source']) . '/', "\\1", $value);
-					$snmp_index = preg_replace((isset($field_array['oid_index_parse']) ? '/' . $field_array['oid_index_parse'] . '/' : $index_parse_regexp), "\\1", $oid);
-					$oid = $field_array['oid'] . '.' . $snmp_index;
-
-					debug_log_insert('data_query', "Found item [$field_name='$value'] index: $snmp_index [from regexp value parse]");
-
-					$output_array[] = data_query_format_record($host_id, $snmp_query_id, $field_name, $rewrite_value, $value, $snmp_index, $oid);
-				}
 			}
 
 			debug_log_insert_section_end('data_query');
