@@ -573,6 +573,10 @@ function tree_edit() {
 
 	html_start_box($header_label, '100%', '', '3', 'center', '');
 
+	if (!sizeof($tree)) {
+		unset($fields_tree_edit['enabled']);
+	}
+
 	draw_edit_form(
 		array(
 			'config' => array('no_form_tag' => true),
@@ -978,10 +982,13 @@ function tree_edit() {
 					},
 					'core' : {
 						'animation' : 0,
-						'check_callback' : true
+						'check_callback' : function(operation, node, node_parent, node_position, more) {
+							return false;  // not dragging onto self
+						}
 					},
 					'dnd' : {
-						'always_copy' : true
+						'always_copy' : true,
+						'check_while_dragging': true
 					},
 					'themes' : { 'stripes' : true },
 					'plugins' : [ 'wholerow', <?php if ($editable) {?>'dnd', <?php }?>'types' ]
